==> haskell-text-short-0.1.2-55-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-short.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-short
version: 0.1.2
id: text-short-0.1.2-GZgz6DYtdiHFXimK6ZiC2
key: text-short-0.1.2-GZgz6DYtdiHFXimK6ZiC2
license: BSD-3-Clause
maintainer: hvr@gnu.org
author: Herbert Valerio Riedel
synopsis: Memory-efficient representation of Unicode text strings
description:
    This package provides the '\''ShortText'\'' type which is suitable for keeping many short strings in memory. This is similiar to how '\''ShortByteString'\'' relates to '\''ByteString'\''.
    .
    The main difference between '\''Text'\'' and '\''ShortText'\'' is that '\''ShortText'\'' uses UTF-8 instead of UTF-16 internally and also doesn'\''t support zero-copy slicing (thereby saving 2 words). Consequently, the memory footprint of a (boxed) '\''ShortText'\'' value is 4 words (2 words when unboxed) plus the length of the UTF-8 encoded payload.
category: Data
abi: a6c2ee5a977acfa36d2fe45c9c0e8e9a
exposed: True
exposed-modules:
    Data.Text.Short Data.Text.Short.Partial Data.Text.Short.Unsafe
hidden-modules: Data.Text.Short.Internal PrimOps
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-short-0.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-short-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-short-0.1.2
hs-libraries: HStext-short-0.1.2-GZgz6DYtdiHFXimK6ZiC2
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2 deepseq-1.4.4.0
    ghc-prim-0.5.3 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-text-short/html/text-short.haddock
haddock-html: /usr/share/doc/haskell-text-short/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-short-0.1.2-56-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-short.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-short
version: 0.1.2
id: text-short-0.1.2-AIAM4X8EhvtBjsFlO9PFc6
key: text-short-0.1.2-AIAM4X8EhvtBjsFlO9PFc6
license: BSD-3-Clause
maintainer: hvr@gnu.org
author: Herbert Valerio Riedel
synopsis: Memory-efficient representation of Unicode text strings
description:
    This package provides the '\''ShortText'\'' type which is suitable for keeping many short strings in memory. This is similiar to how '\''ShortByteString'\'' relates to '\''ByteString'\''.
    .
    The main difference between '\''Text'\'' and '\''ShortText'\'' is that '\''ShortText'\'' uses UTF-8 instead of UTF-16 internally and also doesn'\''t support zero-copy slicing (thereby saving 2 words). Consequently, the memory footprint of a (boxed) '\''ShortText'\'' value is 4 words (2 words when unboxed) plus the length of the UTF-8 encoded payload.
category: Data
abi: 4543613c0dc5695f1cbab52522de5414
exposed: True
exposed-modules:
    Data.Text.Short Data.Text.Short.Partial Data.Text.Short.Unsafe
hidden-modules: Data.Text.Short.Internal PrimOps
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-short-0.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-short-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-short-0.1.2
hs-libraries: HStext-short-0.1.2-AIAM4X8EhvtBjsFlO9PFc6
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2 deepseq-1.4.4.0
    ghc-prim-0.5.3 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-text-short/html/text-short.haddock
haddock-html: /usr/share/doc/haskell-text-short/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
